==> snortsms-0.14.9.tbz: www/snortsms/snortctrl/dsp_AddEdit.php <==
<?
/***************************************************************************
 *   Copyright (C) 2005 by J Randolph Smith                                *
 *   snortsms@servangle.net                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

if ($Fusebox['fuseaction'] == "edit")
	{
	$row = $rsSC->fetchRow(DB_FETCHMODE_ASSOC);
	$temp_id = $row['id'];	
	$temp_title = $row['title'];
	$temp_path = $row['conf_path'];
	$temp_interface = $row['interface'];
	$temp_args = $row['args'];
	$temp_int = $row['interface'];
	$temp_wintitle = "Edit Snort Daemon Profile";
	$temp_button = "Update";
	}
else
	{
	$temp_wintitle = "New Snort Daemon Profile";
	$temp_button = "Save";	
	}


include_once("../lib/func_DrawRepHeader.php");

DrawRepHeader("Snort Daemon Profiles");
?>

<FORM action="index.php?fuseaction=snortctrl.save" method="POST"><INPUT type="hidden" name="FRM_id" value="<?=$temp_id?>">
<div align="center"><table border="0" class="bg1" cellspacing="1" cellpadding="0"><tr class="heading2" align="center"><td><?=$temp_wintitle?></TD></TR><tr><td>

<table border="0" class="bg2"><tr><td colspan="2">&nbsp;</td>
</tr>
<tr>
<td class="label" align="right" valign="top">Title:</td>
<td><input type="text" size="20" name="FRM_title" value="<?=$temp_title?>"></td>
</tr>

<tr>
<td colspan="2">&nbsp;</td></tr><tr><td class="label" align="right" valign="top">Interface to sniff:</td>
<td><input type="text" size="6" name="FRM_int" value="<?=$temp_int?>"></td></tr>
<tr>

<tr>
<td colspan="2">&nbsp;</td></tr><tr><td class="label" align="right" valign="top">Snort Config file location (path only):</td>
<td><input type="text" size="50" name="FRM_path" value="<?=$temp_path?>"></td></tr>
<tr>


<tr>
<td colspan="2">&nbsp;</td></tr><tr><td class="label" align="right" valign="top">Additional Arguments:</td>
<td><input type="text" size="70" name="FRM_args" value="<?=$temp_args?>"></td></tr>
<tr>
<td colspan="2" align="center"><INPUT type="submit" name="BTN_submit" value="<?=$temp_button?>"></td>
</tr>
</table>

</td></tr></TABLE>

</div>

</FORM>

==> snortsms-1.0.0.tbz: www/snortsms/snortctrl/dsp_AddEdit.php <==
<?
/***************************************************************************
 *   Copyright (C) 2005 by J Randolph Smith                                *
 *   snortsms@servangle.net                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

if ($Fusebox['fuseaction'] == "edit")
	{
	$row = $rsSC->fetchRow(DB_FETCHMODE_ASSOC);
	$temp_id = $row['id'];	
	$temp_title = $row['title'];
	$temp_path = $row['conf_path'];
	$temp_interface = $row['interface'];
	$temp_args = $row['snort_args'];
	$temp_int = $row['interface'];
	$temp_wintitle = "Edit Snort Daemon Profile";
	$temp_button = "Update";
	}
else
	{
	$temp_wintitle = "New Snort Daemon Profile";
	$temp_button = "Save";	
	}


include_once("../lib/func_DrawRepHeader.php");

DrawRepHeader("Snort Daemon Profiles");
?>

<FORM action="index.php?fuseaction=snortctrl.save" method="POST"><INPUT type="hidden" name="FRM_id" value="<?=$temp_id?>">
<div align="center"><table border="0" class="bg1" cellspacing="1" cellpadding="0"><tr class="heading2" align="center"><td><?=$temp_wintitle?></TD>
<td align="right">
<a href="#" onclick="help('index.php?fuseaction=help.main&index=snortctrl')"><img src="images/blue_quest.png" width="16" height="14" border="0"></a></td>
</TR>
<tr>
<td colspan="2">

<table border="0" class="bg2"><tr><td colspan="2">&nbsp;</td>
</tr>
<tr>
<td class="label" align="right" valign="top">Title:</td>
<td><input type="text" size="20" name="FRM_title" value="<?=$temp_title?>"></td>
</tr>

<tr>
<td colspan="2">&nbsp;</td></tr><tr><td class="label" align="right" valign="top">Interface to sniff:</td>
<td><input type="text" size="6" name="FRM_int" value="<?=$temp_int?>"></td></tr>
<tr>

<tr>
<td colspan="2">&nbsp;</td></tr><tr><td class="label" align="right" valign="top">Snort Config file location (path only):</td>
<td><input type="text" size="50" name="FRM_path" value="<?=$temp_path?>"></td></tr>
<tr>


<tr>
<td colspan="2">&nbsp;</td></tr><tr><td class="label" align="right" valign="top">Additional Arguments:</td>
<td><input type="text" size="70" name="FRM_args" value="<?=$temp_args?>"></td></tr>
<tr>
<td colspan="2" align="center"><INPUT type="submit" name="BTN_submit" value="<?=$temp_button?>"></td>
</tr>
</table>

</td></tr></TABLE>

</div>

</FORM>
